#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_NBDIGITS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_NBDIGITS_HPP_INCLUDED

#include <boost/simd/constant/include/constants/nbdigits.hpp>

#endif
